==> eiffelstudio-18.07.10.1981.tar: F_code/C1/xm33.c <==
/*
 * Code for class XM_XSLT_DECIMAL_FORMAT_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm33.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.make */
void F41_350 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1467,19,1004,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1458_12090(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.default_decimal_format */
EIF_REFERENCE F41_351 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTLE;
		return (EIF_REFERENCE) loc1;
	} else {
		RTLE;
		return (EIF_REFERENCE) RTOSCF(365,F41_365,(Current));
	}/* NOTREACHED */
	
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.named_format */
EIF_REFERENCE F41_352 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0(NULL, EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = F1458_12095(RTCW(tr1), arg1);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.has_named_format */
EIF_BOOLEAN F41_353 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F41_354(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1458_12095(RTCW(tr1), arg1);
		Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_2_1_);
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.has */
EIF_BOOLEAN F41_354 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1458_12102(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_default_format_set */
EIF_BOOLEAN F41_355 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_different_from_default_format */
EIF_BOOLEAN F41_356 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		tb1 = F1502_12535(RTCW(arg1), loc1);
		RTLE;
		return (EIF_BOOLEAN) tb1;
	}/* NOTREACHED */
	
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_duplicate_format */
EIF_BOOLEAN F41_357 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	tr1 = F41_352(Current, ti4_1);
	Result = F1502_12535(RTCW(arg1), tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.set_default_format */
void F41_358 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	F41_359(Current, arg1);
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.set_named_format */
void F41_359 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,loc2);
	RTLR(6,loc3);
	RTLIU(7);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	if (F41_354(Current, ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
		loc1 = F1458_12095(RTCW(tr1), ti4_1);
		RTCT0("entry_is_list", EX_CHECK);
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_2_0_);
		if (tb1) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTCT0(NULL, EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
		loc4 = tr1;
		if (EIF_TEST(loc4)) {
			RTCK0;
		} else {
			RTCF0;
		}
		loc2 = (EIF_REFERENCE) loc4;
		loc3 = F1439_11861(RTCW(loc2));
		F1275_11048(RTCW(loc3));
		for (;;) {
			tb1 = F1329_11123(RTCW(loc3));
			if (tb1) break;
			tr1 = F1265_11028(RTCW(loc3));
			F1952_19461(RTCW(tr1), arg1);
			F1275_11049(RTCW(loc3));
		}
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
		F1443_11954(RTCW(tr1), ti4_1);
	}
	tr1 = RTLNS(eif_new_type(19, 0x00).id, 19, _OBJSIZ_2_2_0_0_0_0_0_0_);
	F20_156(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	F1458_12111(RTCW(tr1), loc1, ti4_1);
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.fixup_default_default */
void F41_360 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		tr1 = F41_351(Current);
		F41_359(Current, tr1);
	}
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.register_usage */
void F41_361 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc3);
	RTLR(4,arg2);
	RTLR(5,loc4);
	RTLR(6,loc1);
	RTLIU(7);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F1458_12105(RTCW(tr1), arg1);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = F1443_11942(RTCW(tr1));
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		loc2 = F1443_11934(RTCW(tr1));
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_2_0_);
		if (tb1) {
			RTCT0(NULL, EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_);
			loc3 = tr1;
			if (EIF_TEST(loc3)) {
				RTCK0;
			} else {
				RTCF0;
			}
			F1439_11876(loc3, arg2);
		} else {
			RTCT0(NULL, EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			loc4 = tr1;
			if (EIF_TEST(loc4)) {
				RTCK0;
			} else {
				RTCF0;
			}
			F1952_19461(RTCW(arg2), loc4);
		}
	} else {
		{
			static EIF_TYPE_INDEX typarr0[] = {1438,1951,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNS(typres0.id, 1438, _OBJSIZ_4_0_0_2_0_0_0_0_);
		}
		F1439_11856(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		F1439_11871(RTCW(loc1), arg2);
		tr1 = RTLNS(eif_new_type(19, 0x00).id, 19, _OBJSIZ_2_2_0_0_0_0_0_0_);
		F20_157(RTCW(tr1), loc1);
		loc2 = (EIF_REFERENCE) tr1;
		tr1 = *(EIF_REFERENCE *)(Current);
		F1458_12111(RTCW(tr1), loc2, arg1);
	}
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.format_map */
EIF_REFERENCE F41_363 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.default_format */
EIF_REFERENCE F41_364 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.all_defaults */
static EIF_REFERENCE F41_365_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (365);
#define Result RTOSR(365)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1501, 0x00).id, 1501, _OBJSIZ_10_0_0_2_0_0_0_0_);
	F1502_12522(RTCW(tr1), ((EIF_INTEGER_32) -1L), ((EIF_INTEGER_32) -1000000L));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (365);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F41_365 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(365,F41_365_body,(Current));
}

void EIF_Minit33 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C1/xm33.c <==
/*
 * Code for class XM_XSLT_DECIMAL_FORMAT_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm33.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.make */
void F41_368 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1469,19,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1460_12130(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.default_decimal_format */
EIF_REFERENCE F41_369 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTLE;
		return (EIF_REFERENCE) loc1;
	} else {
		RTLE;
		return (EIF_REFERENCE) RTOSCF(383,F41_383,(Current));
	}/* NOTREACHED */
	
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.named_format */
EIF_REFERENCE F41_370 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0("attached format_map.item (a_fingerprint).decimal_format as l_decimal_format", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = F1460_12135(RTCW(tr1), arg1);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.has_named_format */
EIF_BOOLEAN F41_371 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F41_372(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1460_12135(RTCW(tr1), arg1);
		Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_2_1_);
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.has */
EIF_BOOLEAN F41_372 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1460_12142(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_default_format_set */
EIF_BOOLEAN F41_373 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_different_from_default_format */
EIF_BOOLEAN F41_374 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		tb1 = F1504_12575(RTCW(arg1), loc1);
		RTLE;
		return (EIF_BOOLEAN) tb1;
	}/* NOTREACHED */
	
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.is_duplicate_format */
EIF_BOOLEAN F41_375 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	tr1 = F41_370(Current, ti4_1);
	Result = F1504_12575(RTCW(arg1), tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTLE;
	return Result;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.set_default_format */
void F41_376 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	F41_377(Current, arg1);
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.set_named_format */
void F41_377 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,loc2);
	RTLR(6,loc3);
	RTLIU(7);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	if (F41_372(Current, ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
		loc1 = F1460_12135(RTCW(tr1), ti4_1);
		RTCT0("entry_is_list", EX_CHECK);
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_2_0_);
		if (tb1) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTCT0("attached an_entry.list as l_entity_list", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
		loc4 = tr1;
		if (EIF_TEST(loc4)) {
			RTCK0;
		} else {
			RTCF0;
		}
		loc2 = (EIF_REFERENCE) loc4;
		loc3 = F1441_11901(RTCW(loc2));
		F1277_11088(RTCW(loc3));
		for (;;) {
			tb1 = F1331_11163(RTCW(loc3));
			if (tb1) break;
			tr1 = F1267_11068(RTCW(loc3));
			F1954_19501(RTCW(tr1), arg1);
			F1277_11089(RTCW(loc3));
		}
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
		F1445_11994(RTCW(tr1), ti4_1);
	}
	tr1 = RTLNS(eif_new_type(19, 0x00).id, 19, _OBJSIZ_2_2_0_0_0_0_0_0_);
	F20_156(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_10_0_0_0_);
	F1460_12151(RTCW(tr1), loc1, ti4_1);
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.fixup_default_default */
void F41_378 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		tr1 = F41_369(Current);
		F41_377(Current, tr1);
	}
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.register_usage */
void F41_379 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc3);
	RTLR(4,arg2);
	RTLR(5,loc4);
	RTLR(6,loc1);
	RTLIU(7);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F1460_12145(RTCW(tr1), arg1);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = F1445_11982(RTCW(tr1));
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		loc2 = F1445_11974(RTCW(tr1));
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_2_0_);
		if (tb1) {
			RTCT0("attached l_entry.list as l_entity_list", EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_);
			loc3 = tr1;
			if (EIF_TEST(loc3)) {
				RTCK0;
			} else {
				RTCF0;
			}
			F1441_11916(loc3, arg2);
		} else {
			RTCT0("attached l_entry.decimal_format as l_decimal_format", EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			loc4 = tr1;
			if (EIF_TEST(loc4)) {
				RTCK0;
			} else {
				RTCF0;
			}
			F1954_19501(RTCW(arg2), loc4);
		}
	} else {
		{
			static EIF_TYPE_INDEX typarr0[] = {1440,1953,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNS(typres0.id, 1440, _OBJSIZ_4_0_0_2_0_0_0_0_);
		}
		F1441_11896(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		F1441_11911(RTCW(loc1), arg2);
		tr1 = RTLNS(eif_new_type(19, 0x00).id, 19, _OBJSIZ_2_2_0_0_0_0_0_0_);
		F20_157(RTCW(tr1), loc1);
		loc2 = (EIF_REFERENCE) tr1;
		tr1 = *(EIF_REFERENCE *)(Current);
		F1460_12151(RTCW(tr1), loc2, arg1);
	}
	RTLE;
}

/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.format_map */
EIF_REFERENCE F41_381 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.default_format */
EIF_REFERENCE F41_382 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_XSLT_DECIMAL_FORMAT_MANAGER}.all_defaults */
static EIF_REFERENCE F41_383_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (383);
#define Result RTOSR(383)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1503, 0x00).id, 1503, _OBJSIZ_10_0_0_2_0_0_0_0_);
	F1504_12562(RTCW(tr1), ((EIF_INTEGER_32) -1L), ((EIF_INTEGER_32) -1000000L));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (383);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F41_383 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(383,F41_383_body,(Current));
}

void EIF_Minit33 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
